==> mx-packageinstaller-pkglist_19.07.07.tar.xz: mx-packageinstaller-pkglist/OBS-studio.pm <==
<?xml version="1.0"?>
<app>


<category>
Screencast
</category>

<name>
OBS-Studio
</name>

<description>
   <am>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</am>
   <ar>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</ar>
   <bg>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</bg>
   <ca>OBS-Studio - Streaming Video i Screencaster (cal maquinari OpenGL 3)</ca>
   <cs>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</cs>
   <da>OBS-Studio - Streaming af video og skærmudsendelse (kræver OpenGL 3-hardware)</da>
   <de>OBS-Studio - Streaming Video und Screencaster (OpenGL 3 Hardware erforderlich)</de>
   <el>OBS-Studio - Video Streaming και Screencaster (Απαιτείται hardware με OpenGL 3)</el>
   <en>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</en>
   <es>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</es>
   <et>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</et>
   <eu>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</eu>
   <fa>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</fa>
   <fi>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</fi>
   <fr>OBS-Studio - Diffusion vidéo et capture vidéo d'écran (support OpenGL 3 nécessaire)</fr>
   <he_IL>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</he_IL>
   <hi>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</hi>
   <hr>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</hr>
   <hu>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</hu>
   <id>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</id>
   <is>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</is>
   <it>OBS-Studio - Strumento di registrazione e streaming di contenuti video (è richiesto hardware OpenGL 3)</it>
   <ja_JP>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</ja_JP>
   <ja>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</ja>
   <kk>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</kk>
   <ko>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</ko>
   <lt>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</lt>
   <mk>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</mk>
   <nb>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</nb>
   <nl>OBS-Studio - Video en Screencaster Streamen (OpenGL 3 hardware vereist)</nl>
   <pl>strumieniowanie wideo i nagrywanie ekranu komputera (wymagany sprzęt OpenGL 3)</pl>
   <pt_BR>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</pt_BR>
   <pt>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</pt>
   <ro>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</ro>
   <ru>Потоковое видео и видеотрансляции экрана (требуется OpenGL 3 оборудование)</ru>
   <sk>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</sk>
   <sl>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</sl>
   <sq>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</sq>
   <sr>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</sr>
   <sv>OBS-Studio - Strömmande Video och Skärminspelare (OpenGL 3 hårdvara krävs)</sv>
   <tr>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</tr>
   <uk>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</uk>
   <zh_CN>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</zh_CN>
   <zh_TW>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/014/886/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
obs-studio
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
obs-studio
</uninstall_package_names>

</app>

==> mx-packageinstaller-pkglist_19.09.01.tar.xz: mx-packageinstaller-pkglist/OBS-studio.pm <==
<?xml version="1.0"?>
<app>


<category>
Screencast
</category>

<name>
OBS-Studio
</name>

<description>
   <am>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</am>
   <ar>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</ar>
   <bg>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</bg>
   <ca>OBS-Studio - Streaming Video i Screencaster (cal maquinari OpenGL 3)</ca>
   <cs>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</cs>
   <da>OBS-Studio - Streaming af video og skærmudsendelse (kræver OpenGL 3-hardware)</da>
   <de>OBS-Studio - Streaming Video und Screencaster (OpenGL 3 Hardware erforderlich)</de>
   <el>OBS-Studio - Video Streaming και Screencaster (Απαιτείται hardware με OpenGL 3)</el>
   <en>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</en>
   <es>OBS-Studio - Transmisión de Video y Screencaster (requiere hardware OpenGL 3)</es>
   <et>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</et>
   <eu>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</eu>
   <fa>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</fa>
   <fi>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</fi>
   <fr>OBS-Studio - Diffusion vidéo et capture vidéo d'écran (support OpenGL 3 nécessaire)</fr>
   <he_IL>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</he_IL>
   <hi>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</hi>
   <hr>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</hr>
   <hu>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</hu>
   <id>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</id>
   <is>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</is>
   <it>OBS-Studio - Strumento di registrazione e streaming di contenuti video (è richiesto hardware OpenGL 3)</it>
   <ja_JP>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</ja_JP>
   <ja>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</ja>
   <kk>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</kk>
   <ko>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</ko>
   <lt>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</lt>
   <mk>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</mk>
   <nb>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</nb>
   <nl>OBS-Studio - Video en Screencaster Streamen (OpenGL 3 hardware vereist)</nl>
   <pl>strumieniowanie wideo i nagrywanie ekranu komputera (wymagany sprzęt OpenGL 3)</pl>
   <pt_BR>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</pt_BR>
   <pt>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</pt>
   <ro>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</ro>
   <ru>Потоковое видео и видеотрансляции экрана (требуется OpenGL 3 оборудование)</ru>
   <sk>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</sk>
   <sl>OBS-Studio - program za pretakanje videa in vsebine zaslona (potrebna je OpenGL 3 strojna oprema)</sl>
   <sq>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</sq>
   <sr>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</sr>
   <sv>OBS-Studio - Strömmande Video och Skärminspelare (OpenGL 3 hårdvara krävs)</sv>
   <tr>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</tr>
   <uk>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</uk>
   <zh_CN>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</zh_CN>
   <zh_TW>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/014/886/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
obs-studio
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
obs-studio
</uninstall_package_names>

</app>
